@@ -1,11 +1,10 @@
 APP = "apigeecli"
 CMD = "apigee"
-__version__ = "0.36.2"
+__version__ = "0.37.1"
 description = (
     "Apigee Management API command-line interface with multi-factor authentication"
 )
-long_description = (
-    """Apigee Management API command-line interface with multi-factor authentication
+long_description = """Apigee Management API command-line interface with multi-factor authentication
 
 Getting Help:
 
@@ -18,7 +17,6 @@ Getting Help:
     The Apigee Management API command-line interface documentation:
         https://mdelotavo.github.io/apigee-cli/
     """
-)
 
 import json
 from os import getenv
