@@ -15,9 +15,12 @@ import random
 import requests
 import string
 
+from tqdm import tqdm
+
 from apigee import APIGEE_ADMIN_API_URL
 from apigee.abstract.api.apps import IApps, AppsSerializer
-from apigee.api.developers import Developers
+
+# from apigee.api.developers import Developers
 from apigee.util import authorization, console
 
 
@@ -158,7 +161,7 @@ class Apps(IApps):
         developer,
         prefix=None,
         expand=False,
-        count=100,
+        count=1000,
         startkey="",
         format="json",
     ):
@@ -199,17 +202,32 @@ class Apps(IApps):
         return AppsSerializer().serialize_details(resp, format, prefix=prefix)
 
     def list_apps_for_all_developers(
-        self, prefix=None, expand=False, count=100, startkey="", format="dict"
+        self,
+        prefix=None,
+        expand=False,
+        count=1000,
+        startkey="",
+        format="dict",
+        progress_bar=False,
     ):
         apps = {}
-        for dev in Developers(self._auth, self._org_name, None).list_developers(
-            prefix=prefix, expand=expand, count=count, startkey=startkey, format="dict"
-        ):
+        from apigee.api.developers import Developers
+
+        list_of_developers = Developers(
+            self._auth, self._org_name, None
+        ).list_developers(
+            prefix=None, expand=expand, count=count, startkey=startkey, format="dict"
+        )
+        if progress_bar:
+            list_of_developers = tqdm(
+                list_of_developers, desc="List apps for developers"
+            )
+        for dev in list_of_developers:
             apps[dev] = self.list_developer_apps(
                 dev,
-                prefix=None,
+                prefix=prefix,
                 expand=expand,
-                count=1000,
+                count=count,
                 startkey=startkey,
                 format=format,
             )
